==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/f4/f4ecc566517e33eec40d397998ea4cc1.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/css/libraries/multiselect/switch.png */
class __TwigTemplate_2bb4a4d4c7b805c2e8b44aa2cfd01165 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000m\000\000
CiCCPICC profile\000\000xڝSwX>eVBl\000\"#Y\000a@Ņ
VHUĂ
H(gAZU\\8ܧ}zy&j\0009R<:OHɽH g\000\000yx~t?o\000\000p.\$P&W\000 \000\"R\000.T\000\000Sd
\000\000\000ly|B\"\000
\000I>\000ة\000آ\000\000(G\$@\000`UR,\000@\".Y2G\000vX@`\000B,\000 8\000C L0ҿ_pH\000˕͗K3w!lBa)f\t\"#HL\000\0008?flŢko\">!\000N_puk[\000V\000h]3\tZ
zy8@P<
%b0>3o~@z\000q@qanvRB1n#ǅ)4\\,XP\"MyRD!ɕ2\tw
\000ONl~Xv\000@~-\000g42y\000\000@+\000͗\000\000\\L\000\000D*AaD@\$<B
AT:18
\\p`\tAa!:b\"\"aH4 Q\"rBj]H#-r9\\@ 2G1Qu@Ơst4]k=Kut\000}c1fa\\E`X&cX5V5cX7va\$^lGXLXC%#W\t1'\"O%zxb:XF&!!%^'_H\$ɒN
!%2IIkHH-S>iL&m O:ňL\t\$RJ5e?2BQͩ:ZImvP/S4u%͛Cˤ-Кigih/t\t݃EЗkw

Hb(k{/LӗT02goUX**|:V~TUsU?yTU^V}FUP\tթU6RwRPQ__c
FHTc!2eXBrV,kMb[Lvv/{LSCsfffqƱ9ٜJ!
{--?-jf~7zھbrup@,:m:u\t6Qu>cy\tGm7046l18c̐ckihhI'&g5x>fob4ek<abi2ۤĤ)͔kfѴt,ܬج9՜kaټEJ6ǖږ|MV>VyVV׬I\\,mWlPW:˶vm))Sn1
9a%m;t;|rtuvlp4éĩWggs5KvSmnz˕ҵܭm=}M.]=AXq㝧/^v^Y^O&0m[{`:>=e>>z\"=#~~~;yN`k5/>B\t
Yroc3g,Z0&L~oL̶Gli})*2.QStqt,֬Yg񏩌;jrvgjlRlc웸xEt\$\t=sl3Ttcܢ˞w<Y5Y|8? BP/OnM򄛅OEQJ<V8;}ChOFu3\tOR+y#MVDެq-9R
i+0(Of++
ym#slLѣRPL/+x[[xHHZ3f#|PظxY\"E#Sw.1]Rdxi}h˲PXRUjyRҥC+W4nZcadUj[V*_pFWN_|ymJHnYJjAІ
_mJtzjʹ5a5[̶6z]V&ֿw{;켵+xWkE}nݏb~ݸGwOŞ{{Ejtolܯ\tmR6H:p囀oڛwpZ*A'ߦ|{PߙHy+:u-m=茣^G~1cu5W(=䂓dN?=ԙyLk]Q]gCϞ?tL_]p\"b%K==G~pH[oeW<tM;js.]yn&%vw
L]zxem``Y\tӇGG#F#
dΓ᧲~VysKXϿyr﫩:#y=}ǽ(@PcǧO>|/9%\000\000\000bKGD\000̿\000\000\000\tpHYs\000\000
\000\000
B(x\000\000\000tIME#*O\000\000JIDAT(͒+q_Ͼ6LR)vZGiAqBrak\"QƁ\\hH־8zzzy~~F1QwoxiO@T<Ѭ[\000hǅD
vރ*r(43HMVԇŶLrX\$I^ݟ8L3rK]
WekP\\!ˁXGzeXM6=\000̅f]x5js@̯P`~*D1T۔|H.ȓF8η8%F cu~Q:hAx'Rbpb5/'p^k<fk\000s(mb\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/css/libraries/multiselect/switch.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/css/libraries/multiselect/switch.png", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/css/libraries/multiselect/switch.png");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/f4/f4ecc566517e33eec40d397998ea4cc1.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/css/libraries/multiselect/switch.png */
class __TwigTemplate_2bb4a4d4c7b805c2e8b44aa2cfd01165 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000m\000\000
CiCCPICC profile\000\000xڝSwX>eVBl\000\"#Y\000a@Ņ
VHUĂ
H(gAZU\\8ܧ}zy&j\0009R<:OHɽH g\000\000yx~t?o\000\000p.\$P&W\000 \000\"R\000.T\000\000Sd
\000\000\000ly|B\"\000
\000I>\000ة\000آ\000\000(G\$@\000`UR,\000@\".Y2G\000vX@`\000B,\000 8\000C L0ҿ_pH\000˕͗K3w!lBa)f\t\"#HL\000\0008?flŢko\">!\000N_puk[\000V\000h]3\tZ
zy8@P<
%b0>3o~@z\000q@qanvRB1n#ǅ)4\\,XP\"MyRD!ɕ2\tw
\000ONl~Xv\000@~-\000g42y\000\000@+\000͗\000\000\\L\000\000D*AaD@\$<B
AT:18
\\p`\tAa!:b\"\"aH4 Q\"rBj]H#-r9\\@ 2G1Qu@Ơst4]k=Kut\000}c1fa\\E`X&cX5V5cX7va\$^lGXLXC%#W\t1'\"O%zxb:XF&!!%^'_H\$ɒN
!%2IIkHH-S>iL&m O:ňL\t\$RJ5e?2BQͩ:ZImvP/S4u%͛Cˤ-Кigih/t\t݃EЗkw

Hb(k{/LӗT02goUX**|:V~TUsU?yTU^V}FUP\tթU6RwRPQ__c
FHTc!2eXBrV,kMb[Lvv/{LSCsfffqƱ9ٜJ!
{--?-jf~7zھbrup@,:m:u\t6Qu>cy\tGm7046l18c̐ckihhI'&g5x>fob4ek<abi2ۤĤ)͔kfѴt,ܬج9՜kaټEJ6ǖږ|MV>VyVV׬I\\,mWlPW:˶vm))Sn1
9a%m;t;|rtuvlp4éĩWggs5KvSmnz˕ҵܭm=}M.]=AXq㝧/^v^Y^O&0m[{`:>=e>>z\"=#~~~;yN`k5/>B\t
Yroc3g,Z0&L~oL̶Gli})*2.QStqt,֬Yg񏩌;jrvgjlRlc웸xEt\$\t=sl3Ttcܢ˞w<Y5Y|8? BP/OnM򄛅OEQJ<V8;}ChOFu3\tOR+y#MVDެq-9R
i+0(Of++
ym#slLѣRPL/+x[[xHHZ3f#|PظxY\"E#Sw.1]Rdxi}h˲PXRUjyRҥC+W4nZcadUj[V*_pFWN_|ymJHnYJjAІ
_mJtzjʹ5a5[̶6z]V&ֿw{;켵+xWkE}nݏb~ݸGwOŞ{{Ejtolܯ\tmR6H:p囀oڛwpZ*A'ߦ|{PߙHy+:u-m=茣^G~1cu5W(=䂓dN?=ԙyLk]Q]gCϞ?tL_]p\"b%K==G~pH[oeW<tM;js.]yn&%vw
L]zxem``Y\tӇGG#F#
dΓ᧲~VysKXϿyr﫩:#y=}ǽ(@PcǧO>|/9%\000\000\000bKGD\000̿\000\000\000\tpHYs\000\000
\000\000
B(x\000\000\000tIME#*O\000\000JIDAT(͒+q_Ͼ6LR)vZGiAqBrak\"QƁ\\hH־8zzzy~~F1QwoxiO@T<Ѭ[\000hǅD
vރ*r(43HMVԇŶLrX\$I^ݟ8L3rK]
WekP\\!ˁXGzeXM6=\000̅f]x5js@̯P`~*D1T۔|H.ȓF8η8%F cu~Q:hAx'Rbpb5/'p^k<fk\000s(mb\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/css/libraries/multiselect/switch.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/css/libraries/multiselect/switch.png", "/var/www/html/production-demo/app/bundles/CoreBundle/Assets/css/libraries/multiselect/switch.png");
    }
}
